//========================================================================
//
// LTKMisc.h
//
// Copyright 1996-2002 Glyph & Cog, LLC
//
//========================================================================

#ifndef LTKMISC_H
#define LTKMISC_H

#ifdef __GNUC__
#pragma interface
#endif

#include "GString.h"

extern void ltkError(char *msg, ...);

#endif
